==> twinlisp-0.1.1.tar.gz: twinlisp/core/OtherMacs.lisp <==
;Copyright (C) 2006 Mikalai Birukou
;
;This file is part of TwinLisp.
;
;    TwinLisp is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    TwinLisp is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with TwinLisp; if not, write to the Free Software
;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
(in-package "TWINLISP")
;; Macro new
(defmacro new (c &rest rest) `(cond ((subtypep ',c 'condition) (make-condition ',c ,@rest)) (t (make-instance ',c ,@rest))))
;; TwinLisp's case
(defmacro tl-case (x elseForm &rest isForms) (let ((xval (gensym))) `(let ((,xval ,x)) (cond ,@(mapcar #'(lambda (isForm) `((or ,@(mapcar #'(lambda (keyVal) `(_==_ ,xval ,keyVal)) (car isForm))) ,@(cdr isForm))) isForms) ,@(cond (elseForm `((t ,@elseForm))))))))
;; TwinLisp's for loop
(defmacro tl-for ((var cont &rest restVars) resFormsList &body body) (let ((it (gensym)) (nextPair (gensym))) `(do* ((,it (iter ,cont)) (,nextPair (multiple-value-list (next ,it)) (multiple-value-list (next ,it))) (,var (first ,nextPair) (first ,nextPair)) ,@restVars) ((_not_ (second ,nextPair)) ,@resFormsList) ,@body)))
;; Ruby inspired
(defmacro tl-times (num res &body body) (let ((i (gensym))) `(do ((,i 0 (_+_ ,i 1))) ((_>=_ ,i ,num) ,res) ,@body)))
;; Shorter names macros
(defmacro var (&rest rest) `(defvar ,@rest))
(defmacro param (&rest rest) `(defparameter ,@rest))
(defmacro const (&rest rest) `(defconstant ,@rest))

==> twinlisp-0.1.2.tar.gz: twinlisp/core/OtherMacs.lisp <==
;Copyright (C) 2006 Mikalai Birukou
;
;This file is part of TwinLisp.
;
;    TwinLisp is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    TwinLisp is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with TwinLisp; if not, write to the Free Software
;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
(in-package "TWINLISP")
;; Macro new
(defmacro new (c &rest rest) `(cond ((subtypep ',c 'condition) (make-condition ',c ,@rest)) (t (make-instance ',c ,@rest))))
;; TwinLisp's case
(defmacro tl-case (x elseForm &rest isForms) (let ((xval (gensym))) `(let ((,xval ,x)) (cond ,@(mapcar #'(lambda (isForm) `((or ,@(mapcar #'(lambda (keyVal) `(_==_ ,xval ,keyVal)) (car isForm))) ,@(cdr isForm))) isForms) ,@(cond (elseForm `((t ,@elseForm))))))))
;; TwinLisp's for loop
(defmacro tl-for ((var cont &rest restVars) resFormsList &body body) (let ((it (gensym)) (nextPair (gensym))) `(do* ((,it (iter ,cont)) (,nextPair (multiple-value-list (next ,it)) (multiple-value-list (next ,it))) (,var (first ,nextPair) (first ,nextPair)) ,@restVars) ((_not_ (second ,nextPair)) ,@resFormsList) ,@body)))
;; TwinLisp times loop
(defmacro tl-times ((var maxVal &rest restVars) resFormsList &body body) `(do* ((,var 0 (_+_ ,var 1)) ,@restVars) ((_>=_ ,var ,maxVal) ,@resFormsList) ,@body))
;; Shorter names macros
(defmacro var (&rest rest) `(defvar ,@rest))
(defmacro param (&rest rest) `(defparameter ,@rest))
(defmacro const (&rest rest) `(defconstant ,@rest))
